/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDEVELOPER
 * Version: 1.0
 */

using NUnit.Framework;
using System;

namespace TopCoder.Document.Index.Persistence.DB
{
    /// <summary>
    /// This class tests <see cref="DBPersistenceConfigurationException"/>. These tests are somewhat simplistic, as is
    /// the tested class itself.
    /// </summary>
    [TestFixture]
    public class TestDBPersistenceConfigurationException
    {
        /// <summary>
        /// Tests the message constructor.
        /// </summary>
        [Test]
        public void TestMessageConstructor()
        {
            Exception e = new DBPersistenceConfigurationException("message");
            Assert.AreEqual("message", e.Message, "The message is as expected.");
            Assert.IsNull(e.InnerException, "The inner exception should be null.");
        }

        /// <summary>
        /// Tests the message constructor with a null message, which is allowed.
        /// </summary>
        [Test]
        public void TestMessageNull()
        {
            new DBPersistenceConfigurationException(null);
        }

        /// <summary>
        /// Tests the two-param constructor.
        /// </summary>
        [Test]
        public void TestDualConstructor()
        {
            Exception inner = new Exception();
            Exception e = new DBPersistenceConfigurationException("message", inner);
            Assert.AreEqual("message", e.Message, "The message is as expected.");
            Assert.AreEqual(inner, e.InnerException, "The inner exception doesn't match.");
        }

        /// <summary>
        /// Tests the two-param constructor with a null message, which is allowed.
        /// </summary>
        [Test]
        public void TestDualMessageNull()
        {
            new DBPersistenceConfigurationException(null, new Exception());
        }

        /// <summary>
        /// Tests the two-param constructor with a null inner exception.
        /// </summary>
        [Test]
        public void TestDualInnerNull()
        {
            new DBPersistenceConfigurationException("message", null);
        }
    }
}
